<html lang="en">
<head>
    <title>Check Out Page</title>
</head>
<body>
<div style="text-align: center">
    <h1>Please do not refresh this page...</h1>
</div>
<form method="post" action="https://securegw.paytm.in/order/process" name="paytm" style="display: none">
    <input type="hidden" name="MID" value="{{ MID }}">
    <input type="hidden" name="WEBSITE" value="{{ WEBSITE }}">
    <input type="hidden" name="ORDER_ID" value="{{ ORDER_ID }}">
    <input type="hidden" name="CUST_ID" value="{{ CUST_ID }}">

    {% if MOBILE_NO %}
        <input type="hidden" name="MOBILE_NO" value="{{ MOBILE_NO }}">
    {% endif %}

    {% if EMAIL %}
        <input type="hidden" name="EMAIL" value="{{ EMAIL }}">
    {% endif %}

    {% if MERC_UNQ_REF %}
        <input type="hidden" name="MERC_UNQ_REF" value="{{ MERC_UNQ_REF }}">
    {% endif %}

    <input type="hidden" name="INDUSTRY_TYPE_ID" value="{{ INDUSTRY_TYPE_ID }}">
    <input type="hidden" name="CHANNEL_ID" value="{{ CHANNEL_ID }}">
    <input type="hidden" name="TXN_AMOUNT" value="{{ TXN_AMOUNT }}">
    <input type="hidden" name="CALLBACK_URL" value="{{ CALLBACK_URL }}">
    <input type="hidden" name="CHECKSUMHASH" value="{{ CHECKSUMHASH }}">
    <script type="text/javascript">
        document.paytm.submit();
    </script>
</form>
</body>
</html>
